<?php

namespace Wordpress\Plugins\CarDealerPress\Inventory\Api;

/**
 * This is the primary class for the SEO Helpers.
 *
 * It uses standard WordPress hooks and helpers for the different APIs it interfaces with.
 *
 * @package WordPress
 * @subpackage Plugin
 * @since 3.0.0
 */

class dynamic_site_headers {

	/**
	 * Public variable for the host of the API we are suposed to request the headers from.
	 *
	 * @since 3.0.0
	 * @access public
	 * @var string
	 */
		public $host = NULL;

	/**
	 * Public variable for the company ID we'll be giving to the API.
	 *
	 * @since 3.0.0
	 * @access public
	 * @var integer
	 */
		public $company_id = 0;

	/**
	 * Public array of the parameters we'll be submitting to the API.
	 *
	 * @since 3.0.0
	 * @access public
	 * @var array
	 */
		public $parameters = array();

	/**
	 * Public array of the headers returned form the API.
	 *
	 * @since 3.0.0
	 * @access public
	 * @var array
	 */
		public $headers = array();

	/**
	 * Public array all requests made within the instance of the object.
	 *
	 * @since 3.0.0
	 * @access public
	 * @var array
	 */
		public $request_stack = array();

	/**
	 * Public variable for the host of the API we are suposed to request the headers from.
	 *
	 * @since 3.0.0
	 * @access public
	 * @var string
	 */
		public $discourage_seo = NULL;

	/**
	 * Sets up object properties and ties into the WordPress procedural hooks. PHP 5 style constructor.
	 *
	 * @since 3.0.0
	 * @return void
	 */
		function __construct( $host , $company_id , $discourage ) {
			$this->host = $host;
			$this->company_id = $company_id;
			$this->discourage_seo = $discourage;

		}

		/**
		* check for SEO company subscription
		**/
		function seo_check() {
			$company_url = urldecode($this->host) . '/api/companies/' . $this->company_id;
			$request_handler_company = new http_request( $company_url , 'dynamic_site_headers' );
			$this->request_stack[] = $company_url;
			$response_company = $request_handler_company->get_file( true );
			$body_company = isset($response_company['body']) && !empty($response_company['body']) ? json_decode($response_company['body']): array();

			return array_key_exists('seo', $body_company);
		}

	/**
	 * Attempt to get the title and meta information from the VMS.
	 *
	 * @since 3.0.0
	 * @return void
	 */
		function get_headers() {

			$taxonomy = isset( $this->parameters[ 'taxonomy' ] ) ? $this->parameters[ 'taxonomy' ] : 'inventory'; unset($this->parameters[ 'taxonomy' ]);
			$sale_class = isset( $this->parameters[ 'saleclass' ] ) ? $this->parameters[ 'saleclass' ] : 'All'; unset($this->parameters[ 'saleclass' ]);
			$year = isset( $this->parameters[ 'year' ] ) ? $this->parameters[ 'year' ] : false; unset($this->parameters[ 'year' ]);
			$make = isset( $this->parameters[ 'make' ] ) ? urlencode( $this->parameters[ 'make' ] ) : 'All'; unset($this->parameters[ 'make' ]);
			$model = isset( $this->parameters[ 'model' ] ) ? urlencode( $this->parameters[ 'model' ] ) : 'All'; unset($this->parameters[ 'model' ]);
			$trim = isset( $this->parameters[ 'trim' ] ) ? urlencode( $this->parameters[ 'trim' ] ) : 'All'; unset($this->parameters[ 'trim' ]);
			$city = isset( $this->parameters[ 'city' ] ) ? urlencode( $this->parameters[ 'city' ] ) : false; unset($this->parameters[ 'city' ]);
			$state = isset( $this->parameters[ 'state' ] ) ? urlencode( $this->parameters[ 'state' ] ) : false; unset($this->parameters[ 'state' ]);
			$vin = isset( $this->parameters[ 'vin' ] ) ? $this->parameters[ 'vin' ] : false; unset($this->parameters[ 'vin' ]);

			// Remove Extras
			unset($this->parameters['per_page']);

			// GEO Override
			$city = (isset($_GET['geo_city'])? $_GET['geo_city']: $city);
			$state = (isset($_GET['geo_state'])? $_GET['geo_state']: $state);

			$base = $year != false ? $year : $sale_class;
			if( $year == false ) {
				$url = urldecode($this->host) . '/' . $this->company_id . '/seo_helpers.json?cu=/' . $taxonomy . '/' . $base . '/All/' . $make . '/' . $model . '/' . $city . '/' . $state . '/';
			} else {
				$url = urldecode($this->host) . '/' . $this->company_id . '/seo_helpers.json?cu=/' . $taxonomy . '/' . $base . '/' . $make . '/' . $model . '/' . $vin . '/' . $city . '/' . $state . '/';
				$this->set_fb_headers($vin);
			}
			if( strtolower( $trim ) != 'all' ) {
				$url .= '?trim=' . urlencode( $trim );
			}
			$url .= '?' . http_build_query( $this->parameters , '' , '&' );
			if ( $this->seo_check() ){
				$request_handler = new http_request( $url , 'dynamic_site_headers' );
				$this->request_stack[] = $url;
				$response = $request_handler->get_file( true );
				$body = isset($response['body']) && !empty($response['body']) ? json_decode($response['body']): array();
			} else {
				$body = false;
			}
			if( $body ) {
				$this->headers[ 'page_title' ] = isset($body->page_title) ? rawurldecode( $body->page_title ) : '';
				$this->headers[ 'page_description' ] = isset($body->page_description) ? $body->page_description : '';
				$this->headers[ 'page_keywords' ] = isset($body->page_keywords) ? $body->page_keywords : '';
				$this->headers[ 'follow' ] = isset($body->follow) ? $body->follow : '';
				$this->headers[ 'index' ] = isset($body->index) ? $body->index : '';
			} else {
				$headers = false;
			}
		}

		// for Facebook posts
		function set_fb_headers($vin){
			$vehicle_url = urldecode($this->host) . '/' . $this->company_id . '/inventory/vehicles.json?vin=' . $vin;
			if (isset($vehicle_url)){
				$response_vehicle = wp_remote_request( $vehicle_url );
				$response_code = wp_remote_retrieve_response_code( $response_vehicle );
				if ( ($response_code = 200) && isset($response_vehicle['body']) ) {
					$vehicle = json_decode($response_vehicle['body']);
					$photo_large = urldecode($vehicle->photos[0]->large);
					$ogimage = str_replace('http://images.dealertrend.com', 'https://s3.amazonaws.com/images.dealertrend.com', $photo_large);
					$this->headers[ 'ogimage' ] = isset($ogimage) ? $ogimage : '';
				}
			}
		}

	/**
	 * Set the new title we get from the API.
	 *
	 * @since 3.0.0
	 * @return string The new title from the API.
	 */
		function set_title() {
			if ($this->seo_check()) {
				return $this->headers[ 'page_title' ] . ' ';
			}
		}

	/**
	 * Set the header information for the site we got back from the VMS.
	 *
	 * @since 3.0.0
	 * @return void
	 */
		function set_head_information() {
			if ( isset($this->headers['ogimage']) ){
				echo '<meta property="og:image" content="' . $this->headers[ 'ogimage' ] . '" />' . "\n";
			}
			if( isset( $this->headers[ 'page_description' ] ) && !empty( $this->headers[ 'page_description' ] ) ) {
				echo '<meta name="Description" content="' . $this->headers[ 'page_description' ] . '" />' . "\n";
			}
			if( isset( $this->headers[ 'page_keywords' ] ) && !empty( $this->headers[ 'page_keywords' ] ) ) {
				echo '<meta name="Keywords" content="' . $this->headers[ 'page_keywords' ] . '" />' . "\n";
			}
			if( empty( $this->discourage_seo ) ) {
				$robots = array();
				if( isset( $this->headers[ 'follow' ] ) && $this->headers[ 'follow' ] != true ) {
					$robots[] = 'nofollow';
				}
				if( isset( $this->headers[ 'index' ] ) && $this->headers[ 'index' ] != true ) {
					$robots[] = 'noindex';
				}
				if( !empty( $robots ) ) {
					echo '<meta name="robots" content="' . implode( $robots , ',' ) . '" />' . "\n";
				}
			} else {
				echo '<meta name="robots" content="nofollow,noindex" />' . "\n";
			}
		}

		function apply_headers( $parameters, $seo ) {
			foreach($seo as $key => $value){
				if( !empty($value) ){
					$parameters[$key] = $value;
				}
			}
			$this->parameters = $parameters;
			$this->get_headers();
			if( $this->headers != false ) {
				add_filter( 'wp_title' , array( &$this , 'set_title' ) );
				add_filter( 'pre_get_document_title' , array( &$this , 'set_title' ), 20 );
				add_action( 'wp_head' , array( &$this , 'set_head_information' ) , 1 );
			}
		}

}

?>
